//-----------------------------------------------------------------------------------------------
// Definitions
// ----------------------------------------------------------------------------------------------

// Address eeprom on RTC module 
#define RTC_EEPROM_ADDRESS 0x50

// Dot matrix LCD
#define HARDWARE_TYPE MD_MAX72XX::FC16_HW
#define MAX_DEVICES 4
#define SPI_SCK    13     // D13 SPI SCK
#define SPI_MOSI   11     // D11 SPI MOSI 
#define SPI_SS     10     // D10 SPI SS
#define SPI_MISO   12     // D12 SPI MISO (not used for LCD)

// Rotary
#define ROT_BUTTON_PIN  4 //D4
#define ROT_ENC1_PIN    7 //D7
#define ROT_ENC2_PIN    8 //D8

// Interrupts
#define INTERRUPT_1HZ 2   // D2 INT0

// PWM output for sound
#define SOUND_OUTPUT 3    // D3
#define SOUND_ON     5    // D5

// Display modes for the time display
#define TIME_MODE_LARGE         1
#define TIME_MODE_SMALL_HHMM    2
#define TIME_MODE_SMALL_HHMMSS  3

// Clock positions in x=columns 0=rightmost dot, 31=leftmost dot
// Based on format HH:MM:ss capital=7x4 small=5x3
// These are used in TIME_MODE_LARGE
#define SEC_LSB      2
#define SEC_MSB      6
#define MIN_LSB     13  
#define MIN_MSB     18
#define HRS_LSB     25
#define HRS_MSB     30
#define SEP_MIN_SEC  8
#define SEP_HRS_MIN 20 

// Clock positions in x=columns 0=rightmost dot, 31=leftmost dot
// Based on format hh:mm small=5x3
// These are used in TIME_MODE_SMALL_HHMM
#define MIN_LSB_SMALL_HHMM      9  
#define MIN_MSB_SMALL_HHMM     13
#define HRS_LSB_SMALL_HHMM     19
#define HRS_MSB_SMALL_HHMM     23
#define SEP_HRS_MIN_SMALL_HHMM 15

// Clock positions in x=columns 0=rightmost dot, 31=leftmost dot
// Based on format hh:mm:ss small=5x3
// These are used in TIME_MODE_SMALL_HHMM
#define SEC_LSB_SMALL_HHMMSS      5
#define SEC_MSB_SMALL_HHMMSS      9
#define MIN_LSB_SMALL_HHMMSS     15  
#define MIN_MSB_SMALL_HHMMSS     19
#define HRS_LSB_SMALL_HHMMSS     25
#define HRS_MSB_SMALL_HHMMSS     29
#define SEP_MIN_SEC_SMALL_HHMMSS 11
#define SEP_HRS_MIN_SMALL_HHMMSS 21

// Timer positions in x=columns 0=rightmost dot, 31=leftmost dot
// Based on format hh:mm:ss capital=7x4 small=5x3
#define TIMER_SEC_LSB      5
#define TIMER_SEC_MSB      9
#define TIMER_MIN_LSB     15  
#define TIMER_MIN_MSB     19
#define TIMER_HRS_LSB     25
#define TIMER_HRS_MSB     29
#define TIMER_SEP_MIN_SEC 11
#define TIMER_SEP_HRS_MIN 21 

// Stopwatch positions in x=columns 0=rightmost dot, 31=leftmost dot
// Based on format MM:ss:mmm small=5x3
#define MSEC0     2
#define MSEC1     6
#define MSEC2     10
#define SEC0      16
#define SEC1      20
#define MIN0      26
#define MIN1      30
#define SW_SEP0   12
#define SW_SEP1   22

// Code to identify a valid value is stored in EEPROM, default (empty) content of EEPROM is 0xFF
#define TIMER_VALID_CODE  39  
#define ALARM_VALID_CODE  96

// Identifier which font is to be used
#define NORMALFONT        true
#define SMALLFONT         false

const word TIMER_ADDRESS = 0;                 // Address of the timer time, using 4 locations of EEPROM memory [0..3]
const word CORRECTION_ADDRESS = 4;            // Address of the correction factor
const word CORRECTION_TIME_ADDRESS = 5;       // Address of the last known correction time (secondsTime when correction was done)
const word TIMER_SOUND_MODE_ADDRESS = 9;      // Address of the timer sound
const word ALARM1_ADDRESS = 10;               // Address of the alarm time, using 4 locations of EEPROM memory [10..13]
const word ALARM1_ON_ADDRESS = 14;            // Address of the alarm on/off
const word ALARM1_SOUND_MODE_ADDRESS = 15;    // Address of the alarm sound
const word ALARM1_REPEAT_ADDRESS = 16;        // Address of the alarm repeat
const word DARK_ON_ADDRESS  = 17;             // Address of the dark mode on/off
const word DUMMY_ADDRESS = 4095;              // Address used for dummy write actions

// Define functions for references
#define TIMER   0
#define ALARM1  1

#define REST 1
